@@ -2206,9 +2206,13 @@ smooth_arrow_merge (SmoothArrowPart *dest_arrow,
              SmoothArrowPart *src_arrow)
 {
   SmoothArrow dummy;
-     
+
+  /* what is this for? */
   smooth_style_get_arrow(src_arrow, 0, 0, &dummy);
-  memcpy(dest_arrow, src_arrow, sizeof(SmoothArrowPart));
+
+  SmoothCopyArrowPart(dest_arrow, src_arrow);
+
+  /* Only used to inherit in one rc style. So this should work fine, I think. */
   dest_arrow->Inherited = NULL;
 }
 
@@ -2339,7 +2343,7 @@ smooth_style_get_arrow(SmoothArrowPart *Part,
 				...
 			}
 	*/
-	SmoothArrowType type = SMOOTH_ARROW_TYPE_NONE;
+	SmoothArrowType type;
 
 	switch (ArrowType)
 	{
@@ -2358,6 +2362,10 @@ smooth_style_get_arrow(SmoothArrowPart *Part,
 		case GTK_ARROW_RIGHT : 
 			type = SMOOTH_ARROW_TYPE_RIGHT;
 		break;
+		
+		default :
+			type = SMOOTH_ARROW_TYPE_NONE;
+		break;
 	}
 
 	if (Part->CompositeArrowsSet[State][type])
